@@ -56,7 +56,7 @@ class Element(ElementBase):
                  contains: bool = False):
         super().__init__(locator, base, timeout, poll_frequency, ignored_exceptions, contains)
         self.logger = logging.getLogger(f"{__name__}.{self.__class__.__name__}")
-        self.logger.info(f"Initialized Element with locator: {self.locator}")
+        self.logger.debug(f"Initialized Element with locator: {self.locator}")
 
     def __repr__(self):
         return f"Element(locator={self.locator}"
@@ -147,8 +147,8 @@ class Element(ElementBase):
                     missed += 1
                     if missed >= 2:
                         break
-        return Elements(generator)
 
+        return Elements(generator)
 
     def get_attributes(self) -> Optional[Dict[str, str]]:
         """Fetch all XML attributes of the element by matching locator against page source.
@@ -170,7 +170,6 @@ class Element(ElementBase):
             self.logger.error(f"Exception in to_xpath: {e}")
             return None
 
-
         while time.time() - start_time < self.timeout:
             try:
                 self._get_driver()
@@ -339,12 +338,12 @@ class Element(ElementBase):
             except WebDriverException:
                 break
 
-    def get_cousin(
+    def from_parent(
             self,
             ancestor_locator: Union[Tuple, Dict[str, str], 'Element'],
             cousin_locator: Union[Tuple, Dict[str, str], 'Element']
     ) -> Union['Element', None]:
-        """Finds a cousin element (same depth relative to a shared ancestor).
+        """Return element (same depth relative to a shared ancestor).
 
         Args:
             ancestor_locator (Union[Tuple, Dict[str, str], 'Element']): The common ancestor to search from.
@@ -390,13 +389,6 @@ class Element(ElementBase):
             self._handle_driver_error(error)
         return None
 
-    def from_parent(
-            self,
-            parent: Union[Tuple, Dict[str, str], 'Element'],
-            locator: Union[Tuple, Dict[str, str], 'Element']
-    ) -> Union['Element', None]:
-        return self.get_cousin(parent,locator)
-
     def get_center(self, element: Optional[WebElement] = None) -> Optional[Tuple[int, int]]:
         """Get the center coordinates of the element.
 
@@ -984,27 +976,28 @@ class Element(ElementBase):
             stacktrace=traceback.format_stack()
         )
 
-    def scroll_down(self, percent: int = 10, speed: int = 2000) -> Union['Element', None]:
+    def scroll_down(self, percent: float = 1, speed: int = 2000, return_bool: bool = False) -> Union['Element', None]:
         self.logger.debug(f"{inspect.currentframe().f_code.co_name}")
-        return self._scroll(direction='down', percent=percent, speed=speed)
+        return self._scroll(direction='down', percent=percent, speed=speed, return_bool=return_bool)
 
-    def scroll_up(self, percent: int = 10, speed: int = 2000) -> Union['Element', None]:
+    def scroll_up(self, percent: float = 1, speed: int = 2000, return_bool: bool = False) -> Union['Element', None]:
         self.logger.debug(f"{inspect.currentframe().f_code.co_name}")
-        return self._scroll(direction='up', percent=percent, speed=speed)
+        return self._scroll(direction='up', percent=percent, speed=speed, return_bool=return_bool)
 
-    def scroll_left(self, percent: int = 10, speed: int = 2000) -> Union['Element', None]:
+    def scroll_left(self, percent: float = 1, speed: int = 2000, return_bool: bool = False) -> Union['Element', None]:
         self.logger.debug(f"{inspect.currentframe().f_code.co_name}")
-        return self._scroll(direction='left', percent=percent, speed=speed)
+        return self._scroll(direction='left', percent=percent, speed=speed, return_bool=return_bool)
 
-    def scroll_right(self, percent: int = 10, speed: int = 2000) -> Union['Element', None]:
+    def scroll_right(self, percent: float = 1, speed: int = 2000, return_bool: bool = False) -> Union['Element', None]:
         self.logger.debug(f"{inspect.currentframe().f_code.co_name}")
-        return self._scroll(direction='right', percent=percent, speed=speed)
+        return self._scroll(direction='right', percent=percent, speed=speed, return_bool=return_bool)
 
-    def _scroll(self, direction: str, percent: int, speed: int) -> Union['Element', None]:
+    def _scroll(self, direction: str, percent: float, speed: int, return_bool: bool) -> Union['Element', None]:
         """
         direction: Scrolling direction. Mandatory value. Acceptable values are: up, down, left and right (case insensitive)
         percent: The size of the scroll as a percentage of the scrolling area size. Valid values must be float numbers greater than zero, where 1.0 is 100%. Mandatory value.
         speed: The speed at which to perform this gesture in pixels per second. The value must not be negative. The default value is 5000 * displayDensity
+        return_bool: if true return bool else return self
         """
         self.logger.debug(f"{inspect.currentframe().f_code.co_name}")
         # https://github.com/appium/appium-uiautomator2-driver/blob/master/docs/android-mobile-gestures.md#mobile-scrollgesture
@@ -1013,11 +1006,13 @@ class Element(ElementBase):
             try:
                 self._get_driver()
                 self._get_element(locator=self.locator)
-                self._mobile_gesture('mobile: scrollGesture',
-                                     {'elementId': self.id,
-                                      'percent': percent,
-                                      'direction': direction,
-                                      'speed': speed})
+                can_scroll = self._mobile_gesture('mobile: scrollGesture',
+                                                  {'elementId': self.id,
+                                                   'percent': percent,
+                                                   'direction': direction,
+                                                   'speed': speed})
+                if return_bool:
+                    return can_scroll
                 return cast('Element', self)
             except NoSuchDriverException as error:
                 self._handle_driver_error(error)
@@ -1032,77 +1027,47 @@ class Element(ElementBase):
             stacktrace=traceback.format_stack()
         )
 
-    def scroll_to_bottom(self, locator: Union[Tuple, Dict[str, str], str, WebElement, 'Element'] = None) -> Union[
-        'Element', None]:
+    def scroll_to_bottom(self, percent: int = 70, speed: int = 2000) -> 'Element':
+        """Scrolls down until the bottom is reached."""
         self.logger.debug(f"{inspect.currentframe().f_code.co_name}")
-        last_child = None
         start_time = time.time()
 
         while time.time() - start_time < self.timeout:
             try:
-                if isinstance(locator, Element):
-                    locator = locator.locator
-                if not locator:
-                    class_name = self._get_first_child_class()
-                    if not class_name:
-                        raise GeneralElementException("Unable to determine first child class")
-                    locator = {'class': class_name}
-                child = self._get_element(locator=locator)
-                if last_child is not None and child.get_attribute('bounds') == last_child.get_attribute('bounds'):
-                    self.scroll_down()
+                if not self.scroll_up(percent, speed, return_bool=True):
                     return cast('Element', self)
-                last_child = child
-                self.scroll_down()
-            except StaleElementReferenceException:
-                continue
-            except NoSuchDriverException as error:
-                self._handle_driver_error(error)
-            except InvalidSessionIdException as error:
-                self._handle_driver_error(error)
-            except AttributeError as error:
+                self.scroll_down(percent=percent, speed=speed, return_bool=True)
+            except (
+            NoSuchDriverException, InvalidSessionIdException, AttributeError, StaleElementReferenceException) as error:
                 self._handle_driver_error(error)
+
         raise GeneralElementException(
-            msg=f"Failed to {inspect.currentframe().f_code.co_name} within {self.timeout=}",
+            msg=f"Failed to scroll to bottom within {self.timeout=}",
             stacktrace=traceback.format_stack()
         )
 
-    def scroll_to_top(self, locator: Union[Tuple, Dict[str, str], str, WebElement, 'Element'] = None) -> Union[
-        'Element', None]:
+    def scroll_to_top(self, percent: int = 70, speed: int = 2000) -> 'Element':
+        """Scrolls up until the top is reached."""
         self.logger.debug(f"{inspect.currentframe().f_code.co_name}")
-        last_child = None
         start_time = time.time()
 
         while time.time() - start_time < self.timeout:
             try:
-                if isinstance(locator, Element):
-                    locator = locator.locator
-                if not locator:
-                    class_name = self._get_first_child_class()
-                    if not class_name:
-                        raise GeneralElementException("Unable to determine first child class")
-                    locator = {'class': class_name}
-                child = self._get_element(locator=locator)
-                if last_child is not None and child.get_attribute('bounds') == last_child.get_attribute('bounds'):
-                    self.scroll_up()
+                if not self.scroll_up(percent, speed, return_bool=True):
                     return cast('Element', self)
-                last_child = child
-                self.scroll_up()
-            except StaleElementReferenceException:
-                continue
-            except NoSuchDriverException as error:
-                self._handle_driver_error(error)
-            except InvalidSessionIdException as error:
-                self._handle_driver_error(error)
-            except AttributeError as error:
+                self.scroll_up(percent=percent, speed=speed, return_bool=True)
+            except (
+            NoSuchDriverException, InvalidSessionIdException, AttributeError, StaleElementReferenceException) as error:
                 self._handle_driver_error(error)
+
         raise GeneralElementException(
-            msg=f"Failed to {inspect.currentframe().f_code.co_name} within {self.timeout=}",
+            msg=f"Failed to scroll to top within {self.timeout=}",
             stacktrace=traceback.format_stack()
         )
 
     def scroll_to_element(self, locator: Union['Element', Dict[str, str], Tuple[str, str]], max_swipes: int = 30) -> \
-    Union[
-        'Element', None]:
+            Union[
+                'Element', None]:
         self.logger.debug(f"{inspect.currentframe().f_code.co_name}")
         start_time = time.time()
         if isinstance(locator, Element):
@@ -2038,9 +2003,9 @@ class Element(ElementBase):
         self.base.reconnect()
         time.sleep(0.3)
 
-    def _mobile_gesture(self, name: str, params: Union[dict, list]) -> None:
+    def _mobile_gesture(self, name: str, params: Union[dict, list]) -> typing.Any:
         # https://github.com/appium/appium-uiautomator2-driver/blob/master/docs/android-mobile-gestures.md
-        self.driver.execute_script(name, params)
+        return self.driver.execute_script(name, params)
 
     def _ensure_session_alive(self) -> None:
         self.logger.debug(f"{inspect.currentframe().f_code.co_name}")
@@ -2276,4 +2241,3 @@ class Element(ElementBase):
         """Provides DSL-like assertions: element.should.have.text(...), etc."""
         from shadowstep.element.should import Should  # импорт внутри метода для избежания циклической зависимости
         return Should(self)
-
