@@ -4,27 +4,15 @@ import json
 import logging
 import os
 import re
+from collections import defaultdict
 from typing import (
     List, Dict, Union,
-    Set, Tuple, Optional, Any
+    Set, Tuple, Optional, Any, FrozenSet
 )
 from unidecode import unidecode
 from jinja2 import Environment, FileSystemLoader
 
-from shadowstep.page_object.page_object_extractor import PageObjectExtractor
-
-
-def _pretty_dict(d: dict, base_indent: int = 8) -> str:
-    """Форматирует dict в Python-стиле: каждый ключ с новой строки, выровнано по отступу."""
-    lines = ["{"]
-    indent = " " * base_indent
-    for i, (k, v) in enumerate(d.items()):
-        line = f"{indent!s}{repr(k)}: {repr(v)}"
-        if i < len(d) - 1:
-            line += ","
-        lines.append(line)
-    lines.append(" " * (base_indent - 4) + "}")
-    return "\n".join(lines)
+from shadowstep.page_object.page_object_extractor import PageObjectParser
 
 
 class PageObjectGenerator:
@@ -33,14 +21,28 @@ class PageObjectGenerator:
     и Jinja2-шаблона.
     """
 
-    def __init__(self, extractor: PageObjectExtractor):
+    def __init__(self, extractor: PageObjectParser):
         """
         :param extractor: объект, реализующий методы
             - extract_simple_elements(xml: str) -> List[Dict[str,str]]
             - find_summary_siblings(xml: str) -> List[Tuple[Dict, Dict]]
         """
-        self.extractor = extractor
         self.logger = logging.getLogger(__name__)
+        self.BLACKLIST_NO_TEXT_CLASSES = {
+            'android.widget.SeekBar',
+            'android.widget.ProgressBar',
+            'android.widget.Switch',
+            'android.widget.CheckBox',
+            'android.widget.ToggleButton',
+            'android.view.View',
+            'android.widget.ImageView',
+            'android.widget.ImageButton',
+            'android.widget.RatingBar',
+            'androidx.recyclerview.widget.RecyclerView',
+            'androidx.viewpager.widget.ViewPager',
+        }
+        self._anchor_name_map = None
+        self.extractor = extractor
 
         # Инициализируем Jinja2
         templates_dir = os.path.join(
@@ -63,26 +65,21 @@ class PageObjectGenerator:
             self,
             source_xml: str,
             output_dir: str,
+            filename_postfix: str = "",
             max_name_words: int = 5,
             attributes: Optional[
                 Union[Set[str], Tuple[str], List[str]]
-            ] = None
-    ):
-        """
-        Оркестратор:
-          1) получаем приоритет атрибутов
-          2) извлекаем все элементы и пары title/summary
-          3) выбираем заголовок страницы
-          4) формируем имена класса и файла
-          5) собираем список свойств
-          6) рендерим через Jinja2 и пишем файл
-        """
+            ] = None,
+            additional_elements: list = None
+    ) -> Tuple[str, str]:
         # 1) выбор атрибутов для локаторов
         attr_list, include_class = self._prepare_attributes(attributes)
 
         # 2) извлечение и элементов
         elems = self.extractor.parse(source_xml)
-        self.logger.debug(f"{elems=}")
+        if additional_elements:
+            elems += additional_elements
+        # self.logger.debug(f"{elems=}")
 
         # 2.1)
         recycler_id = self._select_main_recycler(elems)
@@ -90,7 +87,7 @@ class PageObjectGenerator:
 
         # 2.2) формирование пар summary
         summary_pairs = self._find_summary_siblings(elems)
-        self.logger.debug(f"{summary_pairs=}")
+        # self.logger.debug(f"{summary_pairs=}")
 
         # 3) заголовок страницы
         title_el = self._select_title_element(elems)
@@ -108,7 +105,7 @@ class PageObjectGenerator:
 
         # 5.1)
         anchor_pairs = self._find_anchor_element_pairs(elems)
-        self.logger.debug(f"{anchor_pairs=}")
+        # self.logger.debug(f"{anchor_pairs=}")
 
         # 5.2) обычные свойства
         for prop in self._build_regular_props(
@@ -173,6 +170,9 @@ class PageObjectGenerator:
             if need_recycler and recycler_el else None
         )
 
+        # 5.7) удаление text из локаторов у элементов, которые не ищутся по text в UiAutomator2
+        properties = self._remove_text_from_non_label_elements(properties)
+
         # 6) рендер и запись
         template = self.env.get_template('page_object.py.j2')
         properties.sort(key=lambda p: p["name"])  # сортировка по алфавиту
@@ -185,15 +185,24 @@ class PageObjectGenerator:
             recycler_locator=recycler_locator,
         )
 
-        self.logger.info(f"Props:\n{json.dumps(properties, indent=2)}")
+        # self.logger.info(f"Props:\n{json.dumps(properties, indent=2)}")
 
-        os.makedirs(output_dir, exist_ok=True)
-        path = os.path.join(output_dir, file_name)
+        # Формируем путь с постфиксом
+        if filename_postfix:
+            name, ext = os.path.splitext(file_name)
+            final_filename = f"{name}{filename_postfix}{ext}"
+        else:
+            final_filename = file_name
+
+        path = os.path.join(output_dir, final_filename)
+        os.makedirs(os.path.dirname(path), exist_ok=True)  # ← вот так
         with open(path, 'w', encoding='utf-8') as f:
             f.write(rendered)
 
         self.logger.info(f"Generated PageObject → {path}")
 
+        return path, class_name
+
     # —————————————————————————————————————————————————————————————————————————
     #                           приватные «стройблоки»
     # —————————————————————————————————————————————————————————————————————————
@@ -303,7 +312,7 @@ class PageObjectGenerator:
             elems: List[Dict[str, str]],
             title_el: Dict[str, str],
             summary_pairs: List[Tuple[Dict[str, str], Dict[str, str]]],
-            attr_list: List[str],
+            attr_list: List[str], # ['text', 'content-desc', 'resource-id']
             include_class: bool,
             max_name_words: int,
             used_names: Set[str],
@@ -314,8 +323,10 @@ class PageObjectGenerator:
             s.get('resource-id', '')
             for _, s in summary_pairs
         }
+        self.logger.info(f"{inspect.currentframe().f_code.co_name}")
 
         for el in elems:
+            self.logger.info(f"{el=}")
             rid = el.get('resource-id', '')
             if el is title_el or rid in processed_ids:
                 continue
@@ -324,11 +335,16 @@ class PageObjectGenerator:
             if not locator:
                 continue
 
-            key = next((k for k in attr_list if el.get(k)), 'resource-id')
-            if key == 'resource-id':
-                raw = self._strip_package_prefix(el.get(key, ''))
+            cls = el.get("class", "")
+            is_blacklisted = cls in self.BLACKLIST_NO_TEXT_CLASSES
+
+            if is_blacklisted:
+                raw = el.get("content-desc") or self._strip_package_prefix(el.get("resource-id", ""))
+                key = "content-desc" if el.get("content-desc") else "resource-id"
             else:
-                raw = el.get(key) or self._strip_package_prefix(rid)
+                key = next((k for k in attr_list if el.get(k)), 'resource-id')
+                raw = el.get(key) or self._strip_package_prefix(el.get('resource-id', ''))
+
             words = self._slug_words(raw)[:max_name_words]
             base = "_".join(words) or key.replace('-', '_')
             suffix = el.get('class', '').split('.')[-1].lower()
@@ -371,26 +387,42 @@ class PageObjectGenerator:
         """Обрезает package-префикс из resource-id, если он есть (например: com.android.settings:id/foo -> foo)."""
         return resource_id.split('/', 1)[-1] if '/' in resource_id else resource_id
 
-    def _filter_duplicates(self, properties: List[Dict]) -> List[Dict]:
+    def _filter_duplicates(self, properties: List[Dict[str, Any]]) -> List[Dict[str, Any]]:
         """
-        Удаляет свойства, у которых одинаковое «базовое имя» (до _1, _2 и т.д.), если таких свойств ≥ 3.
+        Removes duplicate properties based on locator.
+        Keeps:
+          - Summary elements (sibling=True)
+          - Switches (identified by presence of 'anchor_name')
+
+        Args:
+            properties (List[Dict]): List of property dicts with 'locator' and optional 'sibling' / 'anchor_name'
+
+        Returns:
+            List[Dict]: Filtered properties
         """
-        from collections import defaultdict
-
-        base_name_map: Dict[str, List[Dict]] = defaultdict(list)
-        for prop in properties:
-            base = re.sub(r'(_\d+)?$', '', prop['name'])
-            base_name_map[base].append(prop)
+        self.logger.debug(f"{inspect.currentframe().f_code.co_name}()")
 
+        seen: Set[FrozenSet[Tuple[str, str]]] = set()
         filtered: List[Dict] = []
-        for group in base_name_map.values():
-            if len(group) < 3:
-                filtered.extend(group)
+
+        for prop in properties:
+            locator = prop.get("locator", {})
+            loc_key = frozenset(locator.items())  # делаем hashable для set
+
+            is_summary = prop.get("sibling", False)
+            is_switch = "anchor_name" in prop
+
+            if loc_key in seen and not is_summary and not is_switch:
+                self.logger.debug(f"Duplicate locator skipped: {prop['name']} → {locator}")
+                continue
+
+            seen.add(loc_key)
+            filtered.append(prop)
+
         return filtered
 
     def _find_summary_siblings(self, elements: List[Dict[str, Any]]) -> List[Tuple[Dict[str, Any], Dict[str, Any]]]:
         """Find (title, summary) element pairs based on parent and sibling relation."""
-        from collections import defaultdict
 
         # Группируем по родителю
         grouped: Dict[Optional[str], List[Dict[str, Any]]] = defaultdict(list)
@@ -516,7 +548,7 @@ class PageObjectGenerator:
                     f"No anchor found for element {target_el.get('id')} up to depth {max_depth}"
                 )
 
-        self.logger.debug(f"Found anchor-element-depth triplets: {pairs}")
+        # self.logger.debug(f"Found anchor-element-depth triplets: {pairs}")
         return pairs
 
     def _build_switch_prop(
@@ -554,3 +586,32 @@ class PageObjectGenerator:
         locator = self._build_locator(switch_el, attr_list, include_class)
 
         return name, anchor_name, locator, depth
+
+    def _remove_text_from_non_label_elements(self, props: List[Dict]) -> List[Dict]:
+        """
+        Удаляет ключ 'text' из локаторов у элементов, которые не ищутся по text в UiAutomator2.
+        """
+
+
+        for prop in props:
+            locator = prop.get("locator", {})
+            cls = locator.get("class")
+            if cls in self.BLACKLIST_NO_TEXT_CLASSES and "text" in locator:
+                self.logger.debug(f"Удаляем 'text' из локатора {cls} → {locator}")
+                locator.pop("text", None)
+
+        return props
+
+
+
+def _pretty_dict(d: dict, base_indent: int = 8) -> str:
+    """Форматирует dict в Python-стиле: каждый ключ с новой строки, выровнано по отступу."""
+    lines = ["{"]
+    indent = " " * base_indent
+    for i, (k, v) in enumerate(d.items()):
+        line = f"{indent!s}{repr(k)}: {repr(v)}"
+        if i < len(d) - 1:
+            line += ","
+        lines.append(line)
+    lines.append(" " * (base_indent - 4) + "}")
+    return "\n".join(lines)
